;(function(){
  var map = {
  "commitId": "747af1c370e15d18bcdbf2888a996b8345a0846d",
  "branchName": "release-client-6.4.x",
  "buildTime": "2025-05-16 06:55:49 GMT",
  "buildVersion": "1.0.3531",
  "css": [
    "@zoom/client-calendar-desktop/static/css/chunk-vendors.10970a60.css",
    "@zoom/client-calendar-desktop/static/css/app.4427c070.css"
  ],
  "js": [
    "@zoom/client-calendar-desktop/static/js/chunk-vendors.9790e7ee.js",
    "@zoom/client-calendar-desktop/static/js/app.6d675677.js"
  ],
  "key": "@zoom/client-calendar-desktop"
};
  var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
  map.css && map.css.forEach(function (cssItem) {
    var linkTag = document.createElement('link');
    var cssURL = prefix +  cssItem ;
    linkTag.href = cssURL;
    linkTag.setAttribute('rel','stylesheet');
    document.head.appendChild(linkTag);
  });
  map.js && map.js.forEach(function (jsItem) {
    var scriptTag = document.createElement("script");
    var jsURL = prefix +  jsItem;
    scriptTag.setAttribute("src", jsURL);
    document.body.appendChild(scriptTag);
  });
  window.domainFromServer= "https://dev-integration.zoomdev.us/fe-static/";
})();
